import os
import dash
from dash.dependencies import Input, Output
import dash_table
import dash_core_components as dcc
import dash_html_components as html
import plotly.graph_objs as go
import pandas as pd
import numpy as np

# __file__ = '.'
csv_name = os.path.dirname(__file__) + '../statistics.csv'
df = pd.read_csv(csv_name)

df_spec = df.copy()
df_spec.T

# Round floats
df = df.round(2)

variables = {
    'location': '',
    'H_sig': 'o',
    'H_1%': 'x',
    'H_max': '□',
    'Hm0': '◊',
    'Tp': '',
    'Tp1': '',
}

df = df[variables.keys()]

df['id'] = df['location']
df = df.set_index('id', drop=False)

app = dash.Dash(__name__)

app.layout = html.Div([
    dash_table.DataTable(
        id='datatable-row-ids',
        columns=[{
            'name': [val, key],
            'id': key
        } for key, val in variables.items()],
        data=df.to_dict('records'),
        editable=False,
        sort_action='native',
        sort_mode='multi',
        row_selectable='multi',
        row_deletable=False,
        selected_rows=np.arange(df.shape[0]),
        style_as_list_view=True,
        style_cell={
            'minWidth': '100px',
            'width': '100px',
            'maxWidth': '100px',
        },
    ),
    html.Div(id='datatable-row-ids-container')
])


@app.callback(Output('datatable-row-ids-container', 'children'), [
    Input('datatable-row-ids', 'derived_virtual_row_ids'),
    Input('datatable-row-ids', 'selected_row_ids'),
    Input('datatable-row-ids', 'active_cell')
])
def update_graphs(row_ids, selected_row_ids, active_cell):
    # When the table is first rendered, `derived_virtual_data` and
    # `derived_virtual_selected_rows` will be `None`. This is due to an
    # idiosyncracy in Dash (unsupplied properties are always None and Dash
    # calls the dependent callbacks when the component is first rendered).
    # So, if `rows` is `None`, then the component was just rendered
    # and its value will be the same as the component's dataframe.
    # Instead of setting `None` in here, you could also set
    # `derived_virtual_data=df.to_rows('dict')` when you initialize
    # the component.
    selected_id_set = set(selected_row_ids or [])

    if selected_id_set:
        dff = df.loc[selected_id_set]
    else:
        dff = df

    spec = []
    for i, row in dff.iterrows():
        x = np.arange(10)
        y = x * row['H_sig']

        trace = go.Scatter(x=x, y=y, name=i)
        spec.append(trace)

        energy = dict(data=spec)

        graph = dcc.Graph(id='time-series', figure=energy)

    return graph


if __name__ == '__main__':
    app.run_server(debug=False)
